==> data-import-automation-1.1.0.tgz: package/mjs/src/features/aws-s3.js <==
import { BUILD_DIR } from '../constants';
import path from 'path';
export class AwsS3 {
    getGruntConfig() {
        return {
            aws_s3: {
                options: {
                    accessKeyId: process.env.AWS_AccessKeyId,
                    secretAccessKey: process.env.AWS_SecretKey,
                    region: process.env.AWS_Region,
                    bucket: process.env.AWS_Bucket,
                    uploadConcurrency: 5,
                    params: {
                        ContentEncoding: 'application/x-gzip', // applies to all the files!
                    },
                },
                upload_jsonl_gzipped_loader_files: {
                    options: {
                        uploadConcurrency: 5, // 5 simultaneous uploads
                        // Following doesnt actually stop aws unzipping:
                        // mime: {
                        //   "build/"+process.env.EPCC_ENV+"/nodes.jsonl.gz": "application/x-gzip", // prevent aws unzipping
                        //   "build/"+process.env.EPCC_ENV+"/products.jsonl.gz": "application/x-gzip", // prevent aws unzipping
                        // },
                    },
                    files: [
                        {
                            expand: true,
                            cwd: path.join(BUILD_DIR),
                            src: ['*.jsonl.gz.bin'],
                            dest: process.env.AWS_Bucket_Folder,
                            action: 'upload',
                            params: {
                            // Following doesnt actually stop aws unzipping:
                            //ContentEncoding: "application/x-gzip",
                            },
                        },
                    ],
                },
                download_jsonl_gzipped_loader_files: {
                    options: {},
                    files: [
                        {
                            cwd: path.join(BUILD_DIR, 'download') + "/",
                            dest: process.env.AWS_Bucket_Folder,
                            action: 'download',
                        },
                    ],
                },
                delete_jsonl_gzipped_loader_files: {
                    options: {},
                    files: [
                        {
                            dest: process.env.AWS_Bucket_Folder,
                            action: 'delete',
                        },
                    ],
                },
            },
        };
    }
    registerTasks(grunt) {
        grunt.loadNpmTasks('grunt-aws-s3');
        grunt.loadNpmTasks('grunt-http-upload');
    }
}

==> data-import-automation-1.2.0.tgz: package/mjs/src/features/aws-s3.js <==
import { BUILD_DIR, GZIP_AWS_COMPRESS_EXTENSION } from '../constants';
import path from 'path';
export class AwsS3 {
    getGruntConfig() {
        return {
            aws_s3: {
                options: {
                    accessKeyId: process.env.AWS_AccessKeyId,
                    secretAccessKey: process.env.AWS_SecretKey,
                    region: process.env.AWS_Region,
                    bucket: process.env.AWS_Bucket,
                    uploadConcurrency: 5,
                    params: {
                        ContentEncoding: 'application/x-gzip', // applies to all the files!
                    },
                },
                upload_jsonl_gzipped_loader_files: {
                    options: {
                        uploadConcurrency: 5, // 5 simultaneous uploads
                        // Following doesnt actually stop aws unzipping:
                        // mime: {
                        //   "build/"+process.env.EPCC_ENV+"/nodes.jsonl.gz": "application/x-gzip", // prevent aws unzipping
                        //   "build/"+process.env.EPCC_ENV+"/products.jsonl.gz": "application/x-gzip", // prevent aws unzipping
                        // },
                    },
                    files: [
                        {
                            expand: true,
                            cwd: path.join(BUILD_DIR),
                            src: ['*' + GZIP_AWS_COMPRESS_EXTENSION],
                            dest: process.env.AWS_Bucket_Folder,
                            action: 'upload',
                            params: {
                            // Following doesnt actually stop aws unzipping:
                            //ContentEncoding: "application/x-gzip",
                            },
                        },
                    ],
                },
                download_jsonl_gzipped_loader_files: {
                    options: {},
                    files: [
                        {
                            cwd: path.join(BUILD_DIR, 'download') + '/',
                            dest: process.env.AWS_Bucket_Folder,
                            action: 'download',
                        },
                    ],
                },
                delete_jsonl_gzipped_loader_files: {
                    options: {},
                    files: [
                        {
                            dest: process.env.AWS_Bucket_Folder,
                            action: 'delete',
                        },
                    ],
                },
            },
        };
    }
    registerTasks(grunt) {
        grunt.loadNpmTasks('grunt-aws-s3');
        grunt.loadNpmTasks('grunt-http-upload');
    }
}
